mad_scripts_base library

Classes

AnalyzerUtils
Утилитный класс для работы с анализатором Dart и обновлениями файлов.
ArgParser
A class for taking a list of raw command line arguments and parsing out options and flags from them.
ArgResults
The results of parsing a series of command line arguments using ArgParser.parse.
Command<T>
A single command.
CommandRunner<T>
A class for invoking Commands based on raw command-line arguments.
ConfigReader
The ConfigReader class is designed to read and transform configuration files.
Dependency
Represents a Flutter/Dart project dependency that can be defined using a version string, a Git configuration, or a local path. This class provides convenient methods for creating and managing dependencies for insertion or updates in pubspec.yaml.
DependencyUpdater
The DependencyUpdater class is used to update dependencies in a pubspec.yaml file.
FileManager
A helper class for managing files in a directory.
Helper
A utility class containing helper methods for working with the file system and boolean values.
Insertion
A class representing a text insertion at a specific position in the source content.
InsertionBuilder
A class for managing and applying multiple insertions to a source text.
Option
A command-line option.
OptionType
What kinds of values an option accepts.
Output
The Output class provides convenient, formatted console logging.
ScriptCommand<T>
Abstract base class for all project commands. Inherits from Command and provides shared behavior for console commands.
ScriptTemplates
The ScriptTemplates class provides utilities for reading and rendering Mustache templates from files or raw strings.
StopwatchLogger
A class for logging operation execution time using a stopwatch.

Extensions

AstNodeExt on AstNode
Extension for the AstNode class from the analyzer package. Adds helper methods for working with AST nodes.
BlockFunctionBodyExt on BlockFunctionBody
Extension for the BlockFunctionBody class from the analyzer package. Adds helper methods for working with return statements in block-style function bodies.
BoolExt on bool
Extension for the bool class that adds text representation methods based on the value.
ClassNodeExtension on ClassDeclaration
Extension for the ClassDeclaration class from the analyzer package. Adds helper methods for working with class members.
EnumX on List<T>
Extension for List<Enum> that adds helper methods for working with enums.
ExpressionFunctionBodyExt on ExpressionFunctionBody
Extension for the ExpressionFunctionBody class from the analyzer package. Adds helper methods for working with expressions in single-expression function bodies.
FunctionBlockBodyExt on FunctionBody
Extension for the FunctionBody class from the analyzer package. Adds helper methods for working with different types of function bodies.
IterableExtension on Iterable<T>
StringExt on String
Extension for the String class that adds helper methods for working with string formats.
TokenExt on Token
Extension for the Token class from the analyzer package. Adds helper methods for working with tokens.

Properties

output Output
Provides methods to print messages of different types with color indication and optional titled blocks.
latefinal

Functions

input(String title) String
Prompts the user for input with a given title.

Exceptions / Errors

ArgParserException
An exception thrown by ArgParser.
FieldExistsException
Exception thrown when a field already exists.
ScriptException
Exception used for handling errors in scripts.
UsageException