Insertion class

A class representing a text insertion at a specific position in the source content.

Constructors

Insertion({required int offset, required String content})
Creates an instance of Insertion with the given offset and content.
const

Properties

content String
The content to be inserted.
final
hashCode int
The hash code for this object.
no setterinherited
offset int
The position in the string where the content will be inserted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited